import { useState, useEffect } from 'react';
import { Link, useLocation } from 'react-router-dom';
import { Menu, X, Moon, Sun, Calendar, Mail } from 'lucide-react';
import { useTheme } from '../../contexts/ThemeContext';
import type { NavigationItem } from '../../types';

const navigation: NavigationItem[] = [
  { id: 'home', label: 'Home', href: '/' },
  { id: 'about', label: 'About', href: '/about' },
  { id: 'skills', label: 'Skills', href: '/skills' },
  { id: 'projects', label: 'Projects', href: '/projects' },
  { id: 'blog', label: 'Blog', href: '/blog' },
  { id: 'learn', label: 'Learn', href: '/learning' },
  { id: 'contact', label: 'Contact', href: '/contact' },
];

export default function Header() {
  const [isMenuOpen, setIsMenuOpen] = useState(false);
  const [isScrolled, setIsScrolled] = useState(false);
  const { theme, toggleTheme } = useTheme();
  const location = useLocation();  // Track scroll position for enhanced header styling
  useEffect(() => {
    let ticking = false;
    
    const handleScroll = () => {
      if (!ticking) {
        requestAnimationFrame(() => {
          const scrollTop = window.scrollY;
          setIsScrolled(scrollTop > 20);
          ticking = false;
        });
        ticking = true;
      }
    };

    window.addEventListener('scroll', handleScroll, { passive: true });
    return () => window.removeEventListener('scroll', handleScroll);
  }, []);
  // Close mobile menu when clicking outside
  useEffect(() => {
    const handleClickOutside = (event: MouseEvent) => {
      // Don't close if clicking on the menu button or menu content
      const target = event.target as Element;
      if (isMenuOpen && target && !target.closest('header')) {
        setIsMenuOpen(false);
      }
    };

    if (isMenuOpen) {
      document.addEventListener('click', handleClickOutside);
    }

    return () => {
      document.removeEventListener('click', handleClickOutside);
    };
  }, [isMenuOpen]);

  // Close mobile menu on route change
  useEffect(() => {
    setIsMenuOpen(false);
  }, [location.pathname]);

  const isActiveRoute = (href: string) => {
    if (href === '/') {
      return location.pathname === '/';
    }
    return location.pathname.startsWith(href);
  };  const isLearningPage = location.pathname.startsWith('/learning');

  return (
    <header className={`sticky top-0 z-[60] transition-all duration-300 will-change-transform ${
      isScrolled 
        ? 'bg-white/98 dark:bg-gray-900/98 backdrop-blur-lg shadow-lg border-b border-gray-200/90 dark:border-gray-700/90' 
        : 'bg-white/95 dark:bg-gray-900/95 backdrop-blur-md shadow-sm border-b border-gray-200/80 dark:border-gray-700/80'
    }`}>
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex justify-between items-center py-3 lg:py-4 gap-4">{/* Logo */}
          <Link to="/" className="flex items-center space-x-2 group transition-all duration-300 hover:scale-105">
            <div className="w-10 h-10 bg-gradient-to-r from-primary-600 to-secondary-500 rounded-lg flex items-center justify-center flex-shrink-0 group-hover:shadow-lg group-hover:shadow-primary-500/25 transition-all duration-300 group-hover:rotate-3">
              <span className="text-white font-bold text-lg group-hover:scale-110 transition-transform duration-300">MS</span>
            </div>
            <div className="min-w-0 flex-1">
              <h1 className="font-heading font-bold text-lg sm:text-xl text-gray-900 dark:text-white truncate group-hover:text-primary-600 dark:group-hover:text-primary-400 transition-colors duration-300">
                Mohit Suthar
              </h1>
              <p className="text-xs sm:text-sm text-gray-600 dark:text-gray-400 truncate group-hover:text-gray-800 dark:group-hover:text-gray-300 transition-colors duration-300">
                Full-Stack Developer
              </p>
            </div>
          </Link>          {/* Desktop Navigation */}
          <nav className="hidden lg:flex items-center space-x-8">
            {navigation.map((item) => (
              <Link
                key={item.id}
                to={item.href}
                className={`relative font-medium transition-all duration-300 transform hover:scale-105 hover:-translate-y-0.5 group ${
                  isActiveRoute(item.href)
                    ? 'text-primary-600 dark:text-primary-400'
                    : 'text-gray-700 dark:text-gray-300 hover:text-primary-600 dark:hover:text-primary-400'
                }`}
              >
                {item.label}
                {/* Animated underline */}
                <span className={`absolute -bottom-1 left-0 w-0 h-0.5 bg-gradient-to-r from-primary-600 to-secondary-500 transition-all duration-300 group-hover:w-full ${
                  isActiveRoute(item.href) ? 'w-full' : ''
                }`}></span>
                {/* Hover glow effect */}
                <span className="absolute inset-0 rounded-lg bg-primary-600/10 dark:bg-primary-400/10 opacity-0 group-hover:opacity-100 transition-opacity duration-300 -z-10 scale-110"></span>
              </Link>
            ))}
          </nav>{/* Right side actions */}
          <div className="flex items-center space-x-2 sm:space-x-4 flex-shrink-0">            {/* Quick actions - hidden on mobile */}
            <div className="hidden md:flex items-center space-x-3">
              <a
                href="https://calendly.com/kingmohitsuthar"
                target="_blank"
                rel="noopener noreferrer"
                className="flex items-center space-x-2 px-3 py-2 bg-blue-600 hover:bg-blue-700 text-white rounded-lg transition-all duration-300 font-medium text-sm group hover:shadow-lg hover:shadow-blue-500/25 hover:scale-105 hover:-translate-y-0.5"
                aria-label="Schedule Call"
              >
                <Calendar size={16} className="group-hover:rotate-12 transition-transform duration-300" />
                <span>Schedule Call</span>
              </a>
              <a
                href="mailto:kingmohitsuthar@gmail.com"
                className="p-2 rounded-lg text-gray-600 dark:text-gray-400 hover:text-primary-600 dark:hover:text-primary-400 transition-all duration-300 hover:bg-gray-100 dark:hover:bg-gray-700 hover:scale-110 hover:shadow-md group"
                aria-label="Email"
              >
                <Mail size={20} className="group-hover:scale-110 transition-transform duration-300" />
              </a>
            </div>            {/* Theme toggle */}
            <button
              onClick={toggleTheme}
              className="p-2 rounded-lg bg-gray-100 dark:bg-gray-700 text-gray-600 dark:text-gray-400 hover:text-primary-600 dark:hover:text-primary-400 transition-all duration-300 hover:bg-gray-200 dark:hover:bg-gray-600 hover:scale-110 hover:shadow-md group hover:rotate-12"
              aria-label="Toggle theme"
            >
              <div className="group-hover:scale-110 transition-transform duration-300">
                {theme.mode === 'dark' ? <Sun size={20} /> : <Moon size={20} />}
              </div>
            </button>            {/* Mobile menu button */}
            <button
              onClick={(e) => {
                e.stopPropagation();
                setIsMenuOpen(!isMenuOpen);
              }}
              className="lg:hidden p-2 rounded-lg bg-gray-100 dark:bg-gray-700 text-gray-600 dark:text-gray-400 hover:text-primary-600 dark:hover:text-primary-400 transition-all duration-300 hover:bg-gray-200 dark:hover:bg-gray-600 hover:scale-110 hover:shadow-md group mobile-menu-button"
              aria-label="Toggle menu"
            >
              <div className={`group-hover:scale-110 transition-all duration-300 ${isMenuOpen ? 'rotate-90' : ''}`}>
                {isMenuOpen ? <X size={24} /> : <Menu size={24} />}
              </div>
            </button>
          </div>
        </div>        {/* Mobile Navigation */}
        {isMenuOpen && (
          <div className="lg:hidden py-4 border-t border-gray-200 dark:border-gray-700 animate-slide-in-from-top bg-white/95 dark:bg-gray-900/95 backdrop-blur-md">
            <nav className="flex flex-col space-y-4 smooth-transitions">
              {navigation.map((item, index) => (
                <Link
                  key={item.id}
                  to={item.href}
                  className={`relative font-medium transition-all duration-300 hover:translate-x-2 group hover:scale-105 focus-ring ${
                    isActiveRoute(item.href)
                      ? 'text-primary-600 dark:text-primary-400'
                      : 'text-gray-700 dark:text-gray-300 hover:text-primary-600 dark:hover:text-primary-400'
                  }`}
                  style={{ animationDelay: `${index * 50}ms` }}
                  onClick={() => setIsMenuOpen(false)}
                >
                  {item.label}
                  {/* Mobile animated indicator */}
                  <span className={`absolute -left-4 top-1/2 w-2 h-2 bg-primary-600 dark:bg-primary-400 rounded-full transition-all duration-300 transform -translate-y-1/2 ${
                    isActiveRoute(item.href) ? 'opacity-100 scale-100' : 'opacity-0 scale-0 group-hover:opacity-100 group-hover:scale-100'
                  }`}></span>
                  {/* Mobile hover background */}
                  <span className="absolute inset-0 rounded-lg bg-primary-600/5 dark:bg-primary-400/5 opacity-0 group-hover:opacity-100 transition-all duration-300 -z-10 scale-105"></span>
                </Link>
              ))}
                {/* Mobile quick actions */}
              <div className="flex items-center space-x-4 pt-4 border-t border-gray-200 dark:border-gray-700 animate-slide-in-from-bottom">
                <a
                  href="https://calendly.com/kingmohitsuthar"
                  target="_blank"
                  rel="noopener noreferrer"
                  className="flex items-center space-x-2 px-3 py-2 bg-blue-600 hover:bg-blue-700 text-white rounded-lg transition-all duration-300 font-medium text-sm group hover:shadow-lg hover:shadow-blue-500/25 hover:scale-105"
                  aria-label="Schedule Call"
                >
                  <Calendar size={16} className="group-hover:rotate-12 transition-transform duration-300" />
                  <span>Schedule Call</span>
                </a>
                <a
                  href="mailto:kingmohitsuthar@gmail.com"
                  className="p-2 rounded-lg text-gray-600 dark:text-gray-400 hover:text-primary-600 dark:hover:text-primary-400 transition-all duration-300 hover:bg-gray-100 dark:hover:bg-gray-700 hover:scale-110 group"
                  aria-label="Email"
                >
                  <Mail size={20} className="group-hover:scale-110 transition-transform duration-300" />
                </a>
              </div>
            </nav>          </div>
        )}
      </div>
        {/* Enhanced Progress Bar Container for Learning Pages */}
      {isLearningPage && (
        <div id="learning-progress-container" className="absolute bottom-0 left-0 w-full h-1 bg-gray-200/80 dark:bg-gray-700/80 backdrop-blur-sm">
          {/* Progress bar will be rendered here by LearningTopic component */}
        </div>
      )}
    </header>
  );
}
